local mod = RW:Boss("Anub'Arak", "Crusaders Coliseum")
local L

mod.BossIcon = [[Interface\Icons\achievement_boss_anubarak]]

local tSStrike, tSStrikeCD
local tPeneCD
local tBurrow
local tStun
local tAdds
local tSlash

local wSStrike, wSStrikeSoon
local wPersue
local wPene

local mBurrow, mPersue

local iPene, iPersue

function mod:OnRegister()
	L = self:RegisterLocale(self:GetName(), "enUS", true)
	if L then
		L.name = "Anub'Arak"
		
		L.YellPull = "This place will serve as your tomb!"
		
		L.emote_emerge	= "%s emerges from the ground!"
		L.emote_burrow	= "%s burrows into the ground!"
		
		L.burrow_opt	= "Submerge/Emerge"
		L.burrow_t_opt	= "Timer"
		L.burrow_m_otp	= "10s warning"
		L.burrow_timer	= "%s"
		L.burrow_msg	= "%s in 10s"
		L.burrow_text	= "Burrow"
		L.emerge_text	= "Emerge"
		
		L.adds_msg		= "New Burrowers"
		L.adds_subopt	= "Timer for next wave"
		L.adds_opt		= "Add waves"
	end
	
	L = self:GetLocale()
	mod.L = L
	
	local burrowIcon = [[Interface\Icons\INV_Misc_EngGizmos_05]]
	
	mod:AddToCategory("Hard Mode", 66134)
	
	mod:SetTrigger(L.YellPull, 34564)
	mod:SetWin(34564)
	
	tSStrike, tSStrikeCD	= self:CastTimer(66134), self:CDTimer(30, 66134)
	tPeneCD					= self:CDTimer(18, 67700)
	tBurrow					= self:CustomTimer(80, L.burrow_timer, L.burrow_t_opt, burrowIcon, L.burrow_opt)
	tStun					= self:CustomTimer(3, "Stun: %s", "The duration of the stun", [[Interface\Icons\ability_warrior_shockwave]], "Stun timer")
	tAdds					= self:CustomTimer(45, L.adds_msg, L.adds_subopt, 66333, L.adds_opt)
	tSlash					= self:CDTimer(20, 66012, nil, nil, false)
	
	mBurrow					= self:CustomMessage(L.burrow_msg, L.burrow_m_otp, burrowIcon, L.burrow_opt)
	mPersue					= self:TargetMessage(67574)
	
	wSStrike				= self:CastWarning(66134)
	wPersue					= self:RunawayWarning(67574)
	wPene					= self:Warning(67700)
	
	iPene					= self:Icon("CROSS", 67700, false, 17, "SQUARE", "MOON", "TRIANGLE", "DIAMOND")
	iPersue					= self:Icon("SKULL", 67574, false, 20)
end

local sscount
local ssSpam
local addsCount
local phase
local stunSpamm

function StrikeHandler()
	if mod:IsHeroic() then
		tSStrikeCD:Stop()
		if sscount == 0 then
			tSStrikeCD:Start(35.5)
			mod:Schedule("ShadowStrike", 35.5, StrikeHandler)
		else
			tSStrikeCD:Start(30.5)
			mod:Schedule("ShadowStrike", 30.5, StrikeHandler)
		end
		
		sscount = sscount + 1
		
		if sscount > 4 then sscount = 0 end
	end
end

function AddHandler()
	if addsCount == 0 then
		tAdds:Start(5)
		mod:Schedule("Adds", 5, AddHandler)
	else
		tAdds:Start()
		mod:Schedule("Adds", 45, AddHandler)
	end
	
	addsCount = addsCount + 1
end

function mod:OnEngage()
	self:Track("SStrike", 66134)
	self:Track("Swarm", 67630, 66118, 68646, 68647, 66240)
	self:Track("PeneCold", 67700, 66013, 68509, 68510)
	self:Track("Persue", 67574)
	self:Track("Stun", 46968, 55918, 52836, 48817, 48816, 27139, 10318, 2812, 57466, 53638, 23979, 28883, 32445)
	self:Track("Slash", 66012)
	
	self:YellTrack("Burrow", L.emote_burrow)
	self:YellTrack("Emerge", L.emote_emerge)

	sscount = 1
	ssSpam = 0
	addsCount = 0
	phase = 1
	stunSpamm = false
	
	tBurrow:Start(L.burrow_text)
	mBurrow:Schedule(70, L.burrow_text)
	
	StrikeHandler()	
	AddHandler()
end

function mod:SStrike(event, args)
	if event == "SPELL_CAST_START" then
		tSStrike:Start()
		wSStrike:Show()
		if (GetTime() - ssSpam) > 4 then
			StrikeHandler()
			ssSpam = GetTime()
		end
	end
end

function mod:Swarm(event, args)
	if event == "SPELL_CAST_START" then
		tBurrow:Stop()
		mBurrow:Cancel()
		phase = 2
	end
end

function mod:PeneCold(event, args)
	if phase == 2 then
		if event == "SPELL_AURA_APPLIED" or event == "SPELL_AURA_REFRESH" then
			if args:IsPlayer() then
				wPene:Show()
			end
			tPeneCD:Start()
		end
	end
	if event == "SPELL_AURA_APPLIED" or event == "SPELL_AURA_REFRESH" then
		iPene:Show(args.dName)
	end
end

function mod:Persue(event, args)
	if event == "SPELL_AURA_APPLIED" or event == "SPELL_AURA_REFRESH" then
		if args:IsPlayer() then
			wPersue:Show()
		end
		mPersue:Show(args.dName)
		iPersue:Show(args.dName)
	
	elseif event == "SPELL_AURA_REMOVED" then
		iPersue:Hide(args.dName)
	end
end

function mod:Slash(event, args)
	if event == "SPELL_AURA_APPLIED" then
		tSlash:Start()
	end
end

local function resetStun()
	stunSpamm = false
end

function mod:Stun(event, args)
	if event == "SPELL_AURA_APPLIED" or event == "SPELL_AURA_REFRESH" then
		local uID = mod:UIDFromGUID(args.dGUID)
		if uID and not stunSpamm then
			local spellName = GetSpellInfo(args.spellID)
			local name, rank, icon, count, debuffType, duration, expirationTime, unitCaster, isStealable =  UnitDebuff(uID, spellName)
			if name then
				tStun:SetIcon(icon)
				tStun:Start(duration, name)
				stunSpamm = true
				self:Schedule("StunReset", 1, resetStun)
			end
		end
	end
end

function mod:Burrow(event, msg, name)
	tBurrow:Stop()
	tBurrow:Start(65, L.emerge_text)
	mBurrow:Schedule(55, L.emerge_text)
	tSStrikeCD:Stop()
	tAdds:Stop()
	self:Unschedule("ShadowStrike")
	self:Unschedule("Adds")
	sscount = 0
	addsCount = 0
end

function mod:Emerge(event, msg, name)
	tBurrow:Stop()
	tBurrow:Start(75, L.burrow_text)
	mBurrow:Schedule(65, L.burrow_text)
	
	StrikeHandler()	
	AddHandler()
end
