--[[
   Description of pluign, purpose, usage and so on
]]--

----------------------------------
-- Create plugin
local plugin = RW:Plugin("Colors")
if not plugin then return end

----------------------------------
-- Locals 
local AceGUI = LibStub("AceGUI-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("RW-2.0-Plugins")
local db
local Utils = RW.Utils


local defaults = {
	profile = {
		PluginEnabled = true,
		Colors = {
		},
	}
}

----------------------------------
-- Init

function plugin:OnRegister()
	for name, module in RW:IteratePlugins() do
		if module.Colors then
			defaults.profile.Colors[module:GetName()] = {}
			for color, data in pairs(module.Colors) do
				defaults.profile.Colors[module:GetName()][color] = {
					name = data.name,
					description = data.description,
					color = data.color
				}
			end
		end
	end
	
	self.db = RW.db:RegisterNamespace("Colors", defaults)
	db = self.db.profile
	
	self.db.RegisterCallback(self, "OnProfileChanged", "Reset")
	self.db.RegisterCallback(self, "OnProfileCopied", "Reset")
	self.db.RegisterCallback(self, "OnProfileReset", "Reset")	
end

function plugin:PluginEnable()
	if not db.PluginEnabled then
		self:Disable()
		return
	end
end

function plugin:PluginDisable()
end

function plugin:Reset()
	db = self.db.profile
end


function plugin:GetColor(module, color)
	if db.Colors[module] and Utils:InTable2(db.Colors[module], "name", color) then
		return Utils:GetTableData(db.Colors[module], "name", color).color
	end
end

function plugin:GetOptions()
	return "Plugins", "Colors", self.GetGUI, [[Interface\Icons\INV_Sigil_Mimiron]]
end

function plugin:GetGUI()
	self = self or plugin
	local UIF = LibStub("AceGUI-Factory-1.0"):GetFactory("RW")
	
	local group, label, color, check
	
	group = AceGUI:Create("ScrollFrame")
	group:SetLayout("Flow")
	
	label = UIF:MainTitleLabel("Colors")
	group:AddChild(label)
	
	igroup = UIF:InlineGroup("")
	group:AddChild(igroup)	
	
	label = UIF:NormalText("Set Default colors for some plugins")
	label:SetImage([[Interface\Icons\INV_Sigil_Mimiron]])
	igroup:AddChild(label)
	
	igroup = UIF:InlineGroup("")
	group:AddChild(igroup)
	
	for module, CS in pairs(db.Colors) do
		sgroup = UIF:InlineGroup2(module)
		igroup:AddChild(sgroup)
		for i, data in pairs(CS) do
			color = UIF:ColorSelect(data.name, data, "color")
			sgroup:AddChild(color)
			
			if data.description then
				UIF:SetMouseOver(color, nil, data.description)
			end
			
		end
	end
	
	button = UIF:Button(L.RESET_SETTINGS, function() 
		plugin.db:ResetProfile() 
	end)
	
	button:SetUserData("confirm", true)
	button:SetUserData("TriggerGlobalUpdate", true)
	group:AddChild(button)
	
	return group
end
