local mod = RW:Boss("The Lich King", "Icecrown Citadel", "The Frozen Throne")
local L

mod.BossIcon = [[Interface\Icons\achievement_boss_lichking]]
mod.SubCatIcon = [[Interface\Icons\achievement_dungeon_frozenthrone]]

------------------------------------
-- Variables
local mPhase, tActive

-- Shambling Horror
local tShamblingCD, wShambling

-- Infest
local tInfestCD, tInfestCast, wInfest

-- Necrotic Plague
local tNecroticCD, wNecrotic, mNecrotic

-- Soul Reaper
local tReaperCD, wReaper, mReaper

-- Defile
local tDefileCD, wDefileCast, wDefileRun, iDefile

-- Valkyr
local tValkyrCD, wValkyr

-- Harvest Sooul
local tHarvestCD, wHarvest, mHarvest

-- Remorseless Winter
local tRemorselessDur, wRemorseless

-- Vile Spirits
local tSpiritsCD, tSpiritsAttack, wSpirits

-----------------------------------
-- Init

function mod:OnRegister()
	L = mod:RegisterLocale("enUS")
	if L then
		L.name = "The Lich King"
		L.YellTrigger = "So the Light's vaunted justice has finally arrived? Shall I lay down Frostmourne and throw myself at your mercy, Fordring?"
		
		L.defile_on_player = "Defile on me!"
		
		L.plague_emote = "You have been infected by"
		
		L.active = " active"
		L.active_opt = "Timer for when the fight starts"
		L.active_grup = "Fight start"
		
		L.spirits_attack = "Spirits Attacking"
		L.spirits_attack_opt = "Timer for when the Vile spirits will attack"
		
	end
	L = mod:GetLocale()
	mod.L = L
	mod:SetTrigger(36597, L.YellTrigger)
	mod:SetWin()
	mod:SetDelay(60)
	
	mPhase 				= self:PhaseMessage()
	tActive				= self:CustomTimer(55, L.name..L.active, L.active_opt, [[Interface\Icons\achievement_boss_lichking]],  L.active_grup)
	
	-- Shambling Horror
	tShamblingCD		= self:CDTimer(60, 70372)
	wShambling			= self:Warning(70372)
	
	-- Infest
	tInfestCD			= self:CDTimer(20, 70541)
	tInfestCast			= self:CastTimer(70541)
	wInfest				= self:Warning(70541)
	
	-- Necrotic Plague
	tNecroticCD			= self:CDTimer(30, 70337)
	mNecrotic			= self:TargetMessage(70337)
	wNecrotic			= self:RunawayWarning(70337)
	
	-- Soul Reaper
	tReaperCD			= self:CDTimer(30, 69409)
	wReaper				= self:InformWarning(69409)
	mReaper				= self:TargetMessage(69409)
	
	-- Defile
	tDefileCD			= self:CDTimer(30, 72762)
	wDefileCast			= self:CastWarning(72762)
	wDefileRun			= self:RunawayWarning(72762)
	iDefile				= self:Icon("SKULL", 72762, false, 6)
	
	-- Valkyr
	tValkyrCD			= self:CDTimer(47, 71843)
	wValkyr				= self:Warning(71843)
	
	-- Harvest Soul
	tHarvestCD			= self:CDTimer(75, 68980)
	mHarvest			= self:TargetMessage(68980)
	wHarvest			= self:Warning(68980)
	
	-- Remorseless Winter
	tRemorselessDur		= self:DurTimer(60, 74270)
	wRemorseless		= self:RunawayWarning(74270)
	
	-- Vile Spirits
	tSpiritsCD			= self:CDTimer(32, 70498)
	tSpiritsAttack		= self:CustomTimer(15, L.spirits_attack, L.spirits_attack_opt, 70498)
	wSpirits			= self:CastWarning(70498)
end

-----------------------------------------
-- Locals
local defileSpamm

-----------------------------------------
-- Start

function mod:OnEngage(trigger)
	self:Track("ShamblingHorror", 70372)
	self:Track("Infest", 70541, 73779, 73780, 73781)
	self:Track("NercroticPlague", 70337, 70338, 73785, 73786, 73787, 73912, 73913, 73914)
	self:Track("SoulReaper", 69409)
	self:Track("Defile", 72762, 72754, 73708, 73709, 73710) -- First is the spell casted by arthas to summon the Defile
	self:Track("Quake", 72262)
	self:Track("Harvest", 68980)
	self:Track("Remorseless", 74270, 68981, 72259, 74271, 74272, 74273, 74274, 74275)
	self:Track("Valkyr", 69037)
	self:Track("Spirits", 70498)
	
	self:YellTrack("SelfPlague", L.plague_emote)
	
	if  trigger == L.YellTrigger then
		tActive:Start()
	end
	
	defileSpamm = 0
end

function mod:ShamblingHorror(event, args)
	if event == "SPELL_SUMMON" then
		tShamblingCD:Start()
		wShambling:Show()
	end
end

function mod:Infest(event, args)
	if event == "SPELL_CAST_START" then
		tInfestCD:Start()
		tInfestCast:Start()
		wInfest:Show()
	end
end

function mod:NercroticPlague(event, args)
	if event == "SPELL_CAST_SUCCESS" then
		tNecroticCD:Start()
		mNecrotic:Show(args.dName)
	
	elseif event == "SPELL_DISPELL" then
		
	end
end

function mod:SelfPlague(event, msg, name)
	wNecrotic:Show()
end

function mod:SoulReaper(event, args)
	if event == "SPELL_CAST_SUCCESS" then
		tReaperCD:Start()
	
	elseif event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			wReaper:Show()
		end
		mReaper:Show(args.dName)
	end
end

local function ScanDefileTarget()
	local target = mod:GetMobTarget(36597)
	if target then
		iDefile:Show(target)
	
		if target == mod.pName then
			SendChatMessage(L.defile_on_player, "SAY")
			
		elseif mod.Party.group[target] then
			local uID = mod.Party.group[target].id
			if uID and CheckInteractDistance(uID, 2) then
				wDefileRun:Show()
			end
		end
	end
end

function mod:Defile(event, args)
	if event == "SPELL_CAST_START" then
		tDefileCD:Start()
		wDefileCast:Show()
		self:Schedule("DefileScan", 0.1, ScanDefileTarget)
		
	elseif event == "SPELL_DAMAGE" then
		if args:IsPlayer() and GetTime() - defileSpamm > 2 then
			wDefileRun:Show()
			defileSpamm = GetTime()
		end
	end
end

function mod:Quake(event, args)
	if event == "SPELL_CAST_START" then
		mPhase:Show(2)
	end
end

function mod:Harvest(event, args)
	if event == "SPELL_AURA_APPLIED" then
		tHarvestCD:Start()
		mHarvest:Show(args.dName)
		if args:IsPlayer() then
			wHarvest:Show()
		end
	end
end

function mod:Remorseless(event, args)
	if event == "SPELL_CAST_START" then
		wRemorseless:Show()
		tRemorselessDur:Start()
		tReaperCD:Schedule(60, 39)
		tValkyrCD:Schedule(60, 20)
	end
end

function mod:Valkyr(event, args)
	if event == "SPELL_CAST_SUCCESS" then
		wValkyr:Show()
		tValkyrCD:Start()
	end
end

function mod:Spirits(event, args)
	if event == "SPELL_CAST_START" then
		tSpiritsCD:Start()
		tSpiritsAttack:Start()
		wSpirits:Show()
	end
end